import { fetch, post } from '@api/api';

/**
 * 查询用户
 * @param params 请求参数
 * @param headers 请求头
 */
export function queryUserPage(params = {}, headers = {}) {
  return fetch({
    url: '/upms/tenant/user/page',
    params: params,
    headers: headers
  });
}

/**
 * 查询用户账号
 * @param params 请求参数
 * @param headers 请求头
 */
export function queryUserAccount(params = {}, headers = {}) {
  return fetch({
    url: '/upms/tenant/user/account',
    params: params,
    headers: headers
  });
}
/**
 * 变更锁定状态
 * @param params 请求参数
 * @param headers 请求头
 */
export function changeLock(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/change-lock',
    params: params,
    headers: headers
  });
}
/**
 * 重置用户密码
 * @param params 请求参数
 * @param headers 请求头
 */
export function resetPwd(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/reset-pwd',
    params: params,
    headers: headers
  });
}
/**
 * 给用户增加角色
 * @param params 请求参数
 * @param headers 请求头
 */
export function addRole(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/role-add',
    params: params,
    headers: headers
  });
}
/**
 * 给用户移除角色
 * @param params 请求参数
 * @param headers 请求头
 */
export function delRole(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/role-delete',
    params: params,
    headers: headers
  });
}
/**
 * 删除用户
 * @param params 请求参数
 * @param headers 请求头
 */
export function removeUser(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/remove',
    params: params,
    headers: headers
  });
}
/**
 * 查询单个用户
 * @param params 请求参数
 * @param headers 请求头
 */
export function fetchUserById(params = {}, headers = {}) {
  return fetch({
    url: '/upms/tenant/user/detail/by-id',
    params: params,
    headers: headers
  });
}
/**
 * 更新用户
 * @param params 请求参数
 * @param headers 请求头
 */
export function updateUserDetail(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/detail/update',
    params: params,
    headers: headers
  });
}
/**
 * 新增用户
 * @param params 请求参数
 * @param headers 请求头
 */
export function createUser(params = {}, headers = {}) {
  return post({
    url: '/upms/tenant/user/create',
    params: params,
    headers: headers
  });
}
